package org.kantega.jexmec.groovy;

/*
 * Copyright 2011 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLClassLoader;
import java.util.ArrayList;
import java.util.List;

/**
 */
class JexmecGroovyClassLoader extends URLClassLoader {

    private final List<Class> classes = new ArrayList<Class>();

    private long lastModified;
    private final File script;

    public JexmecGroovyClassLoader(File script, ClassLoader parent) {
        super(getUrlArray(script.getParentFile()), parent);
        this.script = script;
    }

    private static URL[] getUrlArray(File directory)  {
        try {
            return new URL[]{directory.toURI().toURL()};
        } catch (MalformedURLException e) {
            throw new RuntimeException(e);
        }
    }

    public void add(Class groovyClass) {
        this.classes.add(groovyClass);
    }

    public List<Class> getClasses() {
        return classes;
    }

    public long getLastModified() {
        return lastModified;
    }

    public void setLastModified(long lastModified) {
        this.lastModified = lastModified;
    }

    public boolean isChanged() {
        return script.lastModified() > lastModified;
    }


}
